@@ -1,16 +1,21 @@
 import re
-from pkg.fig.project import Project
-from pkg.fig.service import VALID_NAME_CHARS,ConfigError
 
+from pkg.fig.project import Project
+from pkg.fig.service import VALID_NAME_CHARS,ConfigError,NAME_RE
 from pkg.fig.cli.docker_client import docker_client
+
 from service import Service
 
 
 
+# import  os
+# os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
+# os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
+# os.environ["DOCKER_TLS_VERIFY"] = '1'
+# os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
 
 
 CONTAINER_NAME_REGEX = '\s+\_\d+\_\s+\_\d+'
-
 DEFAULT_IMAGE = '10.66.128.203:49153/coreqa/splunk:fig'
 
 
@@ -20,10 +25,10 @@ class Environment(object):
     Current support: cluster, dst, shc
 
     '''
+    client = docker_client()
 
     def __init__(self,env_name):
         self.env_name = env_name
-        self.client = docker_client()
 
     @classmethod
     def create_environment(cls,env_type,env_name,image_name = DEFAULT_IMAGE):
@@ -36,15 +41,56 @@ class Environment(object):
 
 
     @classmethod
-    def get_environment(cls):
+    def get_environments(cls):
+
+        all_environment = []
+        all_environment_name_image = cls.get_all_environments_name_image_dict()
+        if len(all_environment_name_image.keys()) != 0:
+            for env_identifier in all_environment_name_image.keys():
+                env_instance = cls.get_environment_by_name(env_identifier, all_environment_name_image[env_identifier])
+                all_environment.append(env_instance)
+
+        return  all_environment
 
-        pass
 
     @classmethod
-    def get_environment_by_name(cls,name):
+    def get_environment_by_name(cls,name,image):
+        env_name,env_type = name.split('_')
+
+        Env_class=ENV_CLASS_MAPPING[env_type]
+        return Env_class(name,image)
 
         pass
 
+
+    @classmethod
+    def get_all_environments_name_image_dict(cls,stopped=False):
+
+        all_environments_name_image = {}
+        for container in cls.client.containers(all=stopped):
+            match = NAME_RE.match(container['Names'][0])
+            if match:
+                env_identifier =  match.group(1).replace("/","")+"_"+match.group(2)
+                if not env_identifier in all_environments_name_image.keys():
+                    all_environments_name_image[env_identifier] = container['Image']
+
+        return all_environments_name_image
+        pass
+
+
+
+    def get_service_names(self):
+
+        service_name = []
+        for service in self._services:
+            if service.name not in service_name:
+                service_name.append(service.name)
+
+        return service_name
+        pass
+
+
+
     def clean(self):
         pass
 
@@ -105,15 +151,15 @@ ENV_DICT_MAPPING = {
 }
 
 
-if __name__ == "__main__":
-    import  os
-    import sys
-    os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
-    os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
-    os.environ["DOCKER_TLS_VERIFY"] = '1'
-    os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
-
-    myEnv = Environment.create_environment("cluster","jacktestapi")
-    myEnv.up()
-    myEnv.indexer.scale(2)
-    print myEnv.indexer.machines[0].name
+# if __name__ == "__main__":
+#
+#
+#     Environment.get_environments()
+#
+#     myEnv = Environment.create_environment("cluster","jacktestapi2")
+#
+#     myEnv.get_service_names()
+#
+#     myEnv.up()
+#     myEnv.indexer.scale(2)
+#     print myEnv.indexer.machines[0].name
